#!/bin/bash

# Automates the packaging process of the software "xorg-driver-linuxwacom" for
# use with Zenwalk Linux.
#	
# Copyright (C) 2009 Michael Verret <michael.verret@gmail.com>

# Summary:	Wacom Drivers from Linux Wacom Project
# Name:		xorg-driver-linuxwacom
# License:	LGPLv2+ and GPLv2+
# Group:	User Interface/X Hardware Support
# URL:		http://linuxwacom.sourceforge.net

# BuildRequires: ncurses
# BuildRequires: xcb
# BuildRequires: xorg-libs

# Source:	http://prdownloads.sourceforge.net/linuxwacom/linuxwacom-0.8.2-2.tar.bz2



# Variables:
#_______________________________________________________________________



Source_Name="linuxwacom"
Software_Name="xorg-driver-linuxwacom"
Source_Version="0.8.2-2"
Software_Version="0.8.2.2"
Release="62"
Build="2"

Flag_Arch='i686'
Package_Arch="${Flag_Arch}"

Special_Docs=" "
Standard_Docs="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"
	
Build_Root=$(pwd)
Package="${Software_Name}-${Software_Version}-${Package_Arch}-${Release}.${Build}"
Installation_Root="${Build_Root}/${Package}"

Sources=" \
	${Source_Name}-${Source_Version}.tar.bz2"
Patches=" \
	linuxwacom-0.7.8.3-sdk-me-harder.patch.gz \
	linuxwacom-0.7.9.7-fix_build.patch.gz \
	linuxwacom-0.8.2.1-fix_build.patch.gz \
	linuxwacom-0.8.2.2-fix-mapping.patch.gz"
Scripts=" \
	build-${Software_Name}.sh"
Miscellaneous=" \
	60-wacom.rules \
	10-linuxwacom.fdi"	
Build_Root=$(pwd)



# Clean & prep:
#_______________________________________________________________________



# Remove cruft and create Installation_Root
	rm -rf ${Package}* ${Package}-src* 1>/dev/null 2>&1
	mkdir ${Installation_Root}
# Check for necessary files:
	for File in ${Sources} ${Patches} ${Scripts} ${Miscellaneous} ; do
		echo -n "${File} :"
		if [ -e ${File} ]; then
			echo " OK"
		else
			echo " MISSING !"
			exit 1
		fi
	done
# Add a package description file:
mkdir -p ${Installation_Root}/install
cat <<EOF0 > ${Installation_Root}/install/slack-desc 
                      |-----handy-ruler------------------------------------------------------|
xorg-driver-linuxwacom: xorg-driver-linuxwacom (Wacom Drivers)
xorg-driver-linuxwacom:
xorg-driver-linuxwacom: The Linux Wacom Project manages the drivers,
xorg-driver-linuxwacom: libraries, and documentation for configuring and
xorg-driver-linuxwacom: running Wacom tablets under the Linux operating
xorg-driver-linuxwacom: system. It contains diagnostic applications as
xorg-driver-linuxwacom: well as X.org XInput drivers.
xorg-driver-linuxwacom:
xorg-driver-linuxwacom:
xorg-driver-linuxwacom:
xorg-driver-linuxwacom:
EOF0
# Install build-scripts patches and miscellaneous items:
	mkdir -p ${Installation_Root}/usr/src/${Software_Name}-${Software_Version}
	cp ${Patches} ${Scripts} ${Miscellaneous} \
	${Installation_Root}/usr/src/${Software_Name}-${Software_Version}/


# Build:
#_______________________________________________________________________



for File in ${Sources} ; do
	Source_Dir="$(basename ${File} .tar.bz2)"
	rm -rf ${Source_Dir}
	tar jxvf ${File}
	cd ${Source_Dir}
# Ensure proper permissions and ownership:
	chown -R root:root .
	find . -perm 666 -exec chmod 644 {} \;
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
# linuxwacom-0.7.8.3-sdk-me-harder.patch:
	zcat ${Build_Root}/linuxwacom-0.7.8.3-sdk-me-harder.patch.gz | patch -p1 -b --suffix=.sdk || exit 1
# linuxwacom-0.7.9.7-fix_build.patch:
	zcat ${Build_Root}/linuxwacom-0.7.9.7-fix_build.patch.gz | patch -p1 || exit 1
# linuxwacom-0.8.2.1-fix_build.patch
	zcat ${Build_Root}/linuxwacom-0.8.2.1-fix_build.patch.gz | patch -p1 || exit 1
# linuxwacom-0.8.2.2-fix-mapping.patch:
	zcat ${Build_Root}/linuxwacom-0.8.2.2-fix-mapping.patch.gz | patch -p1 || exit 1
# Configuration:
	./configure \
	CFLAGS="-O2 -march=${Flag_Arch} -pipe" \
	CXXFLAGS="${CFLAGS}" \
	PKG_CONFIG_PATH=/usr/lib/pkgconfig \
	--prefix=/usr \
	--bindir=/usr/bin \
	--sbindir=/usr/sbin \
	--libexecdir=/usr/libexec \
	--sysconfdir=/etc \
	--sharedstatedir=/usr/com \
	--localstatedir=/var \
	--libdir=/usr/lib \
	--includedir=/usr/include \
	--oldincludedir=/usr/include \
	--infodir=/usr/info \
	--mandir=/usr/man \
	--without-gtk \
	--without-tk \
	--without-tcl \
	--enable-dlloader \
	--silent
# Compilation:
	make --silent || exit 1
	make check || exit 1
# Installation:
	make install --silent  DESTDIR=${Installation_Root} || exit 1
# Documentation:
	mkdir -p ${Installation_Root}/usr/doc/${Source_Dir}/
	for Doc in {${Standard_Docs},${Special_Docs}} ; do
		if [ -e ${Doc} ] ; then
			cp ${Doc} ${Installation_Root}/usr/doc/${Source_Dir}/
		fi
	done
	(
		cd ${Installation_Root}/usr/doc/${Source_Dir}/
		find . -name "*" -size 0c -exec rm {} \;
	)
# Post-build Cleanup:
	cd ${Build_Root}
	rm -rf ${Source_Dir}
done



# Special routines:
#_______________________________________________________________________



# Install udev rules:
	mkdir -p ${Installation_Root}/lib/udev/rules.d
	install -m 0644 ${Build_Root}/60-wacom.rules ${Installation_Root}/lib/udev/rules.d/60-wacom.rules
# This is terribly wrong but I can't be bothered to figure it out right now.
	if [ -e ${Installation_Root}/wacom_drv.so ]; then
		install -m 755 -d ${Installation_Root}/usr/lib/xorg/modules/input
		mv ${Installation_Root}/wacom_drv.so ${Installation_Root}/usr/lib/xorg/modules/input
	fi
# Install hal policies:
	mkdir -p ${Installation_Root}/usr/share/hal/fdi/policy/20thirdparty
	install -m 0644 ${Build_Root}/10-linuxwacom.fdi ${Installation_Root}/usr/share/hal/fdi/policy/20thirdparty



# Packaging:
#_______________________________________________________________________



# Strip binaries:
	(
		cd ${Installation_Root}
		find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
		find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
	)
# Compress the man pages.
	if [ -d ${Installation_Root}/usr/man ]; then
	(
		cd ${Installation_Root}/usr/man
		gzip -9 */*
	)
	fi
# Create dep file:
	(
		cd ${Installation_Root}
		requiredbuilder -z ${Installation_Root} >> ${Build_Root}/${Package}.dep
	)
# Compress the package:
    (
      cd ${Installation_Root}
      makepkg -l y -c n ${Build_Root}/${Package}.tgz
    )
# Calculate the MD5 sum:
    cd ${Build_Root}
      md5sum ${Package}.tgz > ${Package}.md5
# Create a source package and checksum:
	mkdir ${Package}.src
	cp  ${Sources} ${Patches} ${Scripts} ${Miscellaneous} \
		${Package}.src
	tar jcf ${Package}.src.tbz ${Package}.src
	md5sum ${Package}.src.tbz > ${Package}.src.md5
# Post-build cleanup:
	rm -rf ${Installation_Root} ${Package}-src


# Changelog:
#_______________________________________________________________________


# ~ Fri Mar 13th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: xorg-driver-linuxwacom-0.8.2.2
# ~ Build: 62.2

# ~ Wed Feb 4th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: xorg-driver-linuxwacom-0.8.2.2
# ~ Build: 62.1
